###############################
Generic Instrument Types Mixins
###############################

You can use these Mixins as additional parent classes for your instrument.
For more informations, see :ref:`common_instrument_types`.


.. autoclass:: pymeasure.instruments.generic_types.SCPIMixin
    :members:
